==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/datafactory/kotlin/inputs/SnowflakeImportCopyCommandArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datafactory.kotlin.inputs

import com.pulumi.azurenative.datafactory.inputs.SnowflakeImportCopyCommandArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Any
import kotlin.Pair
import kotlin.String
import kotlin.Suppress
import kotlin.collections.Map
import kotlin.jvm.JvmName

/**
 * Snowflake import command settings.
 * @property additionalCopyOptions Additional copy options directly passed to snowflake Copy Command. Type: key value pairs (value should be string type) (or Expression with resultType object). Example: "additionalCopyOptions": { "DATE_FORMAT": "MM/DD/YYYY", "TIME_FORMAT": "'HH24:MI:SS.FF'" }
 * @property additionalFormatOptions Additional format options directly passed to snowflake Copy Command. Type: key value pairs (value should be string type) (or Expression with resultType object). Example: "additionalFormatOptions": { "FORCE": "TRUE", "LOAD_UNCERTAIN_FILES": "'FALSE'" }
 * @property type The import setting type.
 * Expected value is 'SnowflakeImportCopyCommand'.
 */
public data class SnowflakeImportCopyCommandArgs(
    public val additionalCopyOptions: Output<Map<String, Any>>? = null,
    public val additionalFormatOptions: Output<Map<String, Any>>? = null,
    public val type: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.datafactory.inputs.SnowflakeImportCopyCommandArgs> {
    override fun toJava(): com.pulumi.azurenative.datafactory.inputs.SnowflakeImportCopyCommandArgs =
        com.pulumi.azurenative.datafactory.inputs.SnowflakeImportCopyCommandArgs.builder()
            .additionalCopyOptions(
                additionalCopyOptions?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.key.to(args0.value)
                    }).toMap()
                }),
            )
            .additionalFormatOptions(
                additionalFormatOptions?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.key.to(args0.value)
                    }).toMap()
                }),
            )
            .type(type.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [SnowflakeImportCopyCommandArgs].
 */
@PulumiTagMarker
public class SnowflakeImportCopyCommandArgsBuilder internal constructor() {
    private var additionalCopyOptions: Output<Map<String, Any>>? = null

    private var additionalFormatOptions: Output<Map<String, Any>>? = null

    private var type: Output<String>? = null

    /**
     * @param value Additional copy options directly passed to snowflake Copy Command. Type: key value pairs (value should be string type) (or Expression with resultType object). Example: "additionalCopyOptions": { "DATE_FORMAT": "MM/DD/YYYY", "TIME_FORMAT": "'HH24:MI:SS.FF'" }
     */
    @JvmName("ohjxhxkjqqrkblhm")
    public suspend fun additionalCopyOptions(`value`: Output<Map<String, Any>>) {
        this.additionalCopyOptions = value
    }

    /**
     * @param value Additional format options directly passed to snowflake Copy Command. Type: key value pairs (value should be string type) (or Expression with resultType object). Example: "additionalFormatOptions": { "FORCE": "TRUE", "LOAD_UNCERTAIN_FILES": "'FALSE'" }
     */
    @JvmName("mdpbswntijumyjhg")
    public suspend fun additionalFormatOptions(`value`: Output<Map<String, Any>>) {
        this.additionalFormatOptions = value
    }

    /**
     * @param value The import setting type.
     * Expected value is 'SnowflakeImportCopyCommand'.
     */
    @JvmName("ubtojqiwtlrnclju")
    public suspend fun type(`value`: Output<String>) {
        this.type = value
    }

    /**
     * @param value Additional copy options directly passed to snowflake Copy Command. Type: key value pairs (value should be string type) (or Expression with resultType object). Example: "additionalCopyOptions": { "DATE_FORMAT": "MM/DD/YYYY", "TIME_FORMAT": "'HH24:MI:SS.FF'" }
     */
    @JvmName("iamfcnqmeidfdufr")
    public suspend fun additionalCopyOptions(`value`: Map<String, Any>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.additionalCopyOptions = mapped
    }

    /**
     * @param values Additional copy options directly passed to snowflake Copy Command. Type: key value pairs (value should be string type) (or Expression with resultType object). Example: "additionalCopyOptions": { "DATE_FORMAT": "MM/DD/YYYY", "TIME_FORMAT": "'HH24:MI:SS.FF'" }
     */
    @JvmName("mgctnbvsjajxoeog")
    public fun additionalCopyOptions(vararg values: Pair<String, Any>) {
        val toBeMapped = values.toMap()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.additionalCopyOptions = mapped
    }

    /**
     * @param value Additional format options directly passed to snowflake Copy Command. Type: key value pairs (value should be string type) (or Expression with resultType object). Example: "additionalFormatOptions": { "FORCE": "TRUE", "LOAD_UNCERTAIN_FILES": "'FALSE'" }
     */
    @JvmName("eqopmcvemlfhxyht")
    public suspend fun additionalFormatOptions(`value`: Map<String, Any>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.additionalFormatOptions = mapped
    }

    /**
     * @param values Additional format options directly passed to snowflake Copy Command. Type: key value pairs (value should be string type) (or Expression with resultType object). Example: "additionalFormatOptions": { "FORCE": "TRUE", "LOAD_UNCERTAIN_FILES": "'FALSE'" }
     */
    @JvmName("piqxxiqmjmyacymc")
    public fun additionalFormatOptions(vararg values: Pair<String, Any>) {
        val toBeMapped = values.toMap()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.additionalFormatOptions = mapped
    }

    /**
     * @param value The import setting type.
     * Expected value is 'SnowflakeImportCopyCommand'.
     */
    @JvmName("owgdqiokgofgsmwh")
    public suspend fun type(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    internal fun build(): SnowflakeImportCopyCommandArgs = SnowflakeImportCopyCommandArgs(
        additionalCopyOptions = additionalCopyOptions,
        additionalFormatOptions = additionalFormatOptions,
        type = type ?: throw PulumiNullFieldException("type"),
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/datafactory/kotlin/inputs/SnowflakeImportCopyCommandArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datafactory.kotlin.inputs

import com.pulumi.azurenative.datafactory.inputs.SnowflakeImportCopyCommandArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Any
import kotlin.Pair
import kotlin.String
import kotlin.Suppress
import kotlin.collections.Map
import kotlin.jvm.JvmName

/**
 * Snowflake import command settings.
 * @property additionalCopyOptions Additional copy options directly passed to snowflake Copy Command. Type: key value pairs (value should be string type) (or Expression with resultType object). Example: "additionalCopyOptions": { "DATE_FORMAT": "MM/DD/YYYY", "TIME_FORMAT": "'HH24:MI:SS.FF'" }
 * @property additionalFormatOptions Additional format options directly passed to snowflake Copy Command. Type: key value pairs (value should be string type) (or Expression with resultType object). Example: "additionalFormatOptions": { "FORCE": "TRUE", "LOAD_UNCERTAIN_FILES": "'FALSE'" }
 * @property type The import setting type.
 * Expected value is 'SnowflakeImportCopyCommand'.
 */
public data class SnowflakeImportCopyCommandArgs(
    public val additionalCopyOptions: Output<Map<String, Any>>? = null,
    public val additionalFormatOptions: Output<Map<String, Any>>? = null,
    public val type: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.datafactory.inputs.SnowflakeImportCopyCommandArgs> {
    override fun toJava(): com.pulumi.azurenative.datafactory.inputs.SnowflakeImportCopyCommandArgs =
        com.pulumi.azurenative.datafactory.inputs.SnowflakeImportCopyCommandArgs.builder()
            .additionalCopyOptions(
                additionalCopyOptions?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.key.to(args0.value)
                    }).toMap()
                }),
            )
            .additionalFormatOptions(
                additionalFormatOptions?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.key.to(args0.value)
                    }).toMap()
                }),
            )
            .type(type.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [SnowflakeImportCopyCommandArgs].
 */
@PulumiTagMarker
public class SnowflakeImportCopyCommandArgsBuilder internal constructor() {
    private var additionalCopyOptions: Output<Map<String, Any>>? = null

    private var additionalFormatOptions: Output<Map<String, Any>>? = null

    private var type: Output<String>? = null

    /**
     * @param value Additional copy options directly passed to snowflake Copy Command. Type: key value pairs (value should be string type) (or Expression with resultType object). Example: "additionalCopyOptions": { "DATE_FORMAT": "MM/DD/YYYY", "TIME_FORMAT": "'HH24:MI:SS.FF'" }
     */
    @JvmName("uyivqoqdexqkbyts")
    public suspend fun additionalCopyOptions(`value`: Output<Map<String, Any>>) {
        this.additionalCopyOptions = value
    }

    /**
     * @param value Additional format options directly passed to snowflake Copy Command. Type: key value pairs (value should be string type) (or Expression with resultType object). Example: "additionalFormatOptions": { "FORCE": "TRUE", "LOAD_UNCERTAIN_FILES": "'FALSE'" }
     */
    @JvmName("makhhhxadpsoerrg")
    public suspend fun additionalFormatOptions(`value`: Output<Map<String, Any>>) {
        this.additionalFormatOptions = value
    }

    /**
     * @param value The import setting type.
     * Expected value is 'SnowflakeImportCopyCommand'.
     */
    @JvmName("qwgrvvhjjcdxyhxs")
    public suspend fun type(`value`: Output<String>) {
        this.type = value
    }

    /**
     * @param value Additional copy options directly passed to snowflake Copy Command. Type: key value pairs (value should be string type) (or Expression with resultType object). Example: "additionalCopyOptions": { "DATE_FORMAT": "MM/DD/YYYY", "TIME_FORMAT": "'HH24:MI:SS.FF'" }
     */
    @JvmName("mktwimyhxpyaqhcv")
    public suspend fun additionalCopyOptions(`value`: Map<String, Any>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.additionalCopyOptions = mapped
    }

    /**
     * @param values Additional copy options directly passed to snowflake Copy Command. Type: key value pairs (value should be string type) (or Expression with resultType object). Example: "additionalCopyOptions": { "DATE_FORMAT": "MM/DD/YYYY", "TIME_FORMAT": "'HH24:MI:SS.FF'" }
     */
    @JvmName("pqkxdtovxnddhrkk")
    public fun additionalCopyOptions(vararg values: Pair<String, Any>) {
        val toBeMapped = values.toMap()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.additionalCopyOptions = mapped
    }

    /**
     * @param value Additional format options directly passed to snowflake Copy Command. Type: key value pairs (value should be string type) (or Expression with resultType object). Example: "additionalFormatOptions": { "FORCE": "TRUE", "LOAD_UNCERTAIN_FILES": "'FALSE'" }
     */
    @JvmName("tnkihcupovmsinfg")
    public suspend fun additionalFormatOptions(`value`: Map<String, Any>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.additionalFormatOptions = mapped
    }

    /**
     * @param values Additional format options directly passed to snowflake Copy Command. Type: key value pairs (value should be string type) (or Expression with resultType object). Example: "additionalFormatOptions": { "FORCE": "TRUE", "LOAD_UNCERTAIN_FILES": "'FALSE'" }
     */
    @JvmName("eiicixwtrjryoirs")
    public fun additionalFormatOptions(vararg values: Pair<String, Any>) {
        val toBeMapped = values.toMap()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.additionalFormatOptions = mapped
    }

    /**
     * @param value The import setting type.
     * Expected value is 'SnowflakeImportCopyCommand'.
     */
    @JvmName("qnivtyvojucohhiy")
    public suspend fun type(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    internal fun build(): SnowflakeImportCopyCommandArgs = SnowflakeImportCopyCommandArgs(
        additionalCopyOptions = additionalCopyOptions,
        additionalFormatOptions = additionalFormatOptions,
        type = type ?: throw PulumiNullFieldException("type"),
    )
}
